#!/bin/bash

# tst.sh Version 0.2.0 Test btree subroutines
# Copyright (C) 2003-2010  dondalah721@yahoo.com (Dondalah)
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to:
# 
# 	Free Software Foundation, Inc.
# 	59 Temple Place - Suite 330
# 	Boston, MA  02111-1307, USA.

LD_LIBRARY_PATH=../../lib
export LD_LIBRARY_PATH

if [ ! -x initbt ]
then
	echo "Run make -f initbt.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x bldbt ]
then
	echo "Run make -f bldbt.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x delbt ]
then
	echo "Run make -f delbt.mak"
	echo "Then rerun this step"
	exit 1
fi


if [ ! -x tmpbt ]
then
	echo "Run make -f tmpbt.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x btsize ]
then
	echo "Run make -f btsize.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x dbck ]
then
	echo "Run make -f dbck.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x deletes ]
then
	echo "Run make -f deletes.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x depth ]
then
	echo "Run make -f depth.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x lstbt ]
then
	echo "Run make -f lstbt.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x lstbt_r ]
then
	echo "Run make -f lstbt_r.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x lstphys ]
then
	echo "Run make -f lstphys.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x dmpbt ]
then
	echo "Run make -f dmpbt.mak"
	echo "Then rerun this step"
	exit 1
fi

if [ ! -x updtbt ]
then
	echo "Run make -f updtbt.mak"
	echo "Then rerun this step"
	exit 1
fi

echo "Initialize a new database"
rm -f tst.bt
initbt -m new -n 11 -r 16 -k 8 -o 4 -d 0 tst.bt

echo "Now re-configure an existing database"
initbt -m old -n 11 -r 16 -k 8 -o 4 -d 0 tst.bt

# populate the database
bldbt tst.bt 1024 >zzz01

# run a database check on the database
echo "Database Check"
dbck tst.bt >zzz02

# how many levels deep is the database
depth tst.bt >zzz03

# count the records in the database
btsize tst.bt >zzz04

# count the deleted records in the database
deletes tst.bt >zzz05
cat zzz01 zzz02 zzz03 \
   zzz04 zzz05 | less

# print the database in sequence
lstbt tst.bt | less

# print the database in reverse sequence
lstbt_r tst.bt | less

# print the database in physical sequence
lstphys tst.bt | less

# dump the database in hex
dmpbt tst.bt | less

# update the database
# using btgetnext and btupdt
updtbt tst.bt >zzz06

# run a database check on the database
echo "Database Check"
dbck tst.bt >zzz07

# how many levels deep is the database
depth tst.bt >zzz08

# count the records in the database
btsize tst.bt >zzz09

# count the deleted records in the database
deletes tst.bt >zzz10
cat zzz?? | less
# cat zzz06 zzz07 zzz08 \
   # zzz09 zzz10 | less

# populate a temporary database
# Need to re-direct output because piping doesn't
# allow remove to work in btcloset.
# The link number on the database doesn't go to zero.
# With re-direction, it does go to zero.
tmpbt 1024 >lst
less lst

# optimize the database
optimbt 1024 3 | less

echo "Now run holdlock.sh on one logical terminal"
echo "Run tstlock.sh on another terminal"
echo "Terminate holdlock"
echo "Re-run tstlock.sh"

# clean up
rm -f tst.bt
rm -f zzz*
rm -f err lst
